@@ -9,7 +9,7 @@ from django.utils.encoding import smart_text
 from markupfield.markup import DEFAULT_MARKUP_TYPES
 from markupfield.fields import MarkupField, Markup
 from markupfield.widgets import MarkupTextarea, AdminMarkupTextareaWidget
-from markupfield.tests.models import Post, Article, Concrete, NullTestModel, DefaultTestModel
+from markupfield.tests.models import Post, Article, Concrete, NullTestModel, DefaultTestModel, NullDefaultTestModel
 
 from django.forms.models import modelform_factory
 ArticleForm = modelform_factory(Article, fields=['normal_field', 'normal_field_markup_type',
@@ -347,6 +347,17 @@ class NullTestCase(TestCase):
 
 
 class DefaultTestCase(TestCase):
+    def test_default_value_rendered(self):
+        m = DefaultTestModel()
+        m.save()
+        
+        self.assertEqual(
+            m._meta.get_field('_text_rendered').default,
+            m._meta.get_field('text').default
+        )
+
+        self.assertEqual(m._text_rendered, "<p><strong>nice</strong></p>")
+
     def test_default_text_save(self):
         m = DefaultTestModel()
         m.save()
@@ -361,3 +372,18 @@ class DefaultTestCase(TestCase):
         self.assertEqual(smart_text(m.text), '')
         self.assertIsNone(m.text.raw)
         self.assertIsNone(m.text.rendered)
+
+
+class NullDefaultTestCase(TestCase):
+    def test_default_value_rendered(self):
+        m = NullDefaultTestModel()
+        m.save()
+        
+        self.assertEqual(
+            m._meta.get_field('_text_rendered').default,
+            m._meta.get_field('text').default
+        )
+
+        self.assertEqual(m._text_rendered, "<p><em>nice</em></p>")
+    
+
